@@ -8,9 +8,10 @@ import config
 headers = {'content-type': 'application/json'}
 
 def read_and_report_adafruit_scd4x(scd4x):
+    """This method requires installing urequests and ujson from pypi."""
     try:
-        from growmax import urequests
-        from growmax import ujson
+        import urequests
+        import ujson
         data = sensors.read_adafruit_scd4x(scd4x)
         time.sleep(1.0)
         device_id = ubinascii.hexlify(machine.unique_id()).decode()
